@@ -7,7 +7,18 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+/* some jpeg versions re-define TRUE/FALSE .. bad bad so we have to tuck those away */
+#ifdef TRUE
+#undef TRUE
+#endif
+#ifdef FALSE
+#undef FALSE
+#endif
+#define TRUE JPEG_TRUE
+#define FALSE JPEG_FALSE
 #include <jpeglib.h>
+#undef TRUE
+#undef FALSE
 
 #if (BITS_IN_JSAMPLE != 8)
 #error "Sorry, only 8-bit libjpeg is supported"
