@@ -208,9 +208,9 @@ SEXP write_jpeg(SEXP image, SEXP sFn, SEXP sQuality, SEXP sBg, SEXP sColorsp) {
 	    }
 	} else {
 	    if (planes == 4 && cmyk) { /* CMYK - from raw input, not really native */
-		memcpy(flat_rows, (char*) INTEGER(res), rowbytes * height);
+		memcpy(flat_rows, (char*) INTEGER(image), rowbytes * height);
 	    } else if (planes == 4) { /* RGBA */
-		int x, y, *idata = INTEGER(res);
+		int x, y, *idata = INTEGER(image);
 		for (y = 0; y < height; y++)
 		    for (x = 0; x < rowbytes; idata++) {
 			flat_rows[y * rowbytes + x++] = ABLEND(R_RED(*idata),   R_ALPHA(*idata), R_RED(bg));
@@ -218,7 +218,7 @@ SEXP write_jpeg(SEXP image, SEXP sFn, SEXP sQuality, SEXP sBg, SEXP sColorsp) {
 			flat_rows[y * rowbytes + x++] = ABLEND(R_BLUE(*idata),  R_ALPHA(*idata), R_BLUE(bg));
 		    }
 	    } else if (planes == 3) { /* RGB */
-		int x, y, *idata = INTEGER(res);
+		int x, y, *idata = INTEGER(image);
 		for (y = 0; y < height; y++)
 		    for (x = 0; x < rowbytes; idata++) {
 			flat_rows[y * rowbytes + x++] = R_RED(*idata);
@@ -226,12 +226,12 @@ SEXP write_jpeg(SEXP image, SEXP sFn, SEXP sQuality, SEXP sBg, SEXP sColorsp) {
 			flat_rows[y * rowbytes + x++] = R_BLUE(*idata);
 		    }
 	    } else if (planes == 2) { /* GA */
-		int x, y, *idata = INTEGER(res);
+		int x, y, *idata = INTEGER(image);
 		for (y = 0; y < height; y++)
 		    for (x = 0; x < rowbytes; idata++)
 			flat_rows[y * rowbytes + x++] = ABLEND(R_RED(*idata), R_ALPHA(*idata), R_RED(bg));
 	    } else { /* gray */
-		int x, y, *idata = INTEGER(res);
+		int x, y, *idata = INTEGER(image);
 		for (y = 0; y < height; y++)
 		    for (x = 0; x < rowbytes; idata++)
 			flat_rows[y * rowbytes + x++] = R_RED(*idata);
